#include <avr/io.h>
#include <avr/interrupt.h>
#include <string.h>
#include "lcd.h"
#include "usart.h"
#include "i2c.h"
#include "MCP79410.h"

char buffer[64];
volatile uint8_t bufferIndex = 0;
volatile uint8_t newCommand = 0;

int main(void) {
	i2cInit();
	lcdInit();
	lcdInitPrintf();
	usartInit();
	FILE usartStream = FDEV_SETUP_STREAM(&usartPut, &usartGet, _FDEV_SETUP_RW);
	sei();
	//wcz przerwanie
	UCSRB |= _BV(RXCIE);
	while (1) {
		DateTime dateTime;
		rtcReadDateTime(&dateTime);
		lcdGotoXY(0, 0);
		printf("%02d:%02d:%02d", dateTime.hours, dateTime.minutes, dateTime.seconds);
		lcdGotoXY(0, 1);
		printf("%02d-%02d-%4d", dateTime.dayOfMonth, dateTime.month, dateTime.year);
		if (newCommand) {
			newCommand = 0;
			if (strncmp(buffer, "SET", 3) == 0) {
				DateTime newDateTime;
				int n = sscanf(buffer, "SET %hhd:%hhd:%hhd %hhd-%hhd-%d",
					&newDateTime.hours, &newDateTime.minutes, &newDateTime.seconds,
					&newDateTime.dayOfMonth, &newDateTime.month, &newDateTime.year);
				if (n == 6) rtcWriteDateTime(&newDateTime);
			}
			if (strncmp(buffer, "GET", 3) == 0) {
				fprintf(&usartStream, "%02d:%02d:%02d %02d-%02d-%4d\r\n",
					dateTime.hours, dateTime.minutes, dateTime.seconds,
					dateTime.dayOfMonth, dateTime.month, dateTime.year);
			}
		}
	}
}

ISR(USART_RXC_vect) {
	uint8_t value = UDR;
	if (value != '\n' && value != '\n') {
		if (bufferIndex < sizeof(buffer)) {
			buffer[bufferIndex++] = value;
		}
	}
	if (value == '\r') {
		buffer[bufferIndex] = 0;
		bufferIndex = 0;
		newCommand = 1;
	}
}
